# Path: C:\Users\user\projects\config\settings.py
# File: settings.py



import os
import json
from dotenv import load_dotenv

# 현재 파일의 디렉토리를 기준으로 .env 파일 경로 설정
CONFIG_DIR = os.path.dirname(__file__)
ENV_PATH = os.path.join(CONFIG_DIR, '.env')

# .env 파일 로드
if os.path.exists(ENV_PATH):
    load_dotenv(ENV_PATH)
    print(f".env 파일이 성공적으로 로드되었습니다: {ENV_PATH}")
else:
    raise FileNotFoundError(f".env 파일을 찾을 수 없습니다: {ENV_PATH}")

# config.json 파일 로드 (필요한 경우)
CONFIG_JSON_PATH = os.path.join(CONFIG_DIR, 'config.json')
if os.path.exists(CONFIG_JSON_PATH):
    with open(CONFIG_JSON_PATH, 'r', encoding='utf-8') as f:
        config_json = json.load(f)
else:
    config_json = {}
    print(f"config.json 파일을 찾을 수 없습니다: {CONFIG_JSON_PATH}. 기본값을 사용합니다.")

# 환경 변수 및 config.json을 결합하여 모듈 수준 변수로 설정
STOCK_DATA_PATH = config_json.get("STOCK_DATA_PATH", os.getenv("STOCK_DATA_PATH"))
DATA_PATH = config_json.get("DATA_PATH", os.getenv("DATA_PATH"))
NEWS_DATA_DIR = config_json.get("NEWS_DATA_DIR", os.getenv("NEWS_DATA_DIR"))
FINANCIAL_DATA_DIR = config_json.get("FINANCIAL_DATA_DIR", os.getenv("FINANCIAL_DATA_DIR"))
ECONOMIC_DATA_DIR = config_json.get("ECONOMIC_DATA_DIR", os.getenv("ECONOMIC_DATA_DIR"))
TOKEN_PATH = config_json.get("TOKEN_PATH", os.getenv("TOKEN_PATH"))
MODEL_PATH = config_json.get("MODEL_PATH", os.getenv("MODEL_PATH"))
STOCK_CODES_PATH = config_json.get("STOCK_CODES_PATH", os.getenv("STOCK_CODES_PATH"))
STOCK_N_CODES_PATH = config_json.get("STOCK_N_CODES_PATH", os.getenv("STOCK_N_CODES_PATH"))
APPROVAL_KEY = os.getenv("APPROVAL_KEY")
MAX_DETECTED_STOCKS = int(os.getenv("MAX_DETECTED_STOCKS", 99))
DATA_FETCH_INTERVAL = int(os.getenv("DATA_FETCH_INTERVAL", 60))
STRATEGY_NAME = os.getenv("STRATEGY_NAME")
APPKEY = os.getenv("APPKEY")
APPSECRET = os.getenv("APPSECRET")
DART_API_KEY = os.getenv("DART_API_KEY")
USER_ID = os.getenv("USER_ID")
TRADING_URL = os.getenv("TRADING_URL")
TRADING_BASE_URL = os.getenv("TRADING_BASE_URL")
AGENT = os.getenv("AGENT")
ACCT_STOCK = os.getenv("ACCT_STOCK")
PROD = os.getenv("PROD")
CANO = os.getenv("CANO")
SEQ = os.getenv("SEQ")
PROD_URL = os.getenv("PROD_URL")
ALERT_SENDER_EMAIL = os.getenv("ALERT_SENDER_EMAIL")
ALERT_SENDER_PASSWORD = os.getenv("ALERT_SENDER_PASSWORD")
ALERT_RECEIVER_EMAIL = os.getenv("ALERT_RECEIVER_EMAIL")
SMTP_SERVER = os.getenv("SMTP_SERVER")
TOKEN_PATH = config_json.get("TOKEN_PATH")
SMTP_PORT = int(os.getenv("SMTP_PORT", 587))
ALERT_THRESHOLD_CPU = float(os.getenv("ALERT_THRESHOLD_CPU", 80.0))
ALERT_THRESHOLD_MEMORY = float(os.getenv("ALERT_THRESHOLD_MEMORY", 80.0))
TARGET_RETURN_RATE = float(os.getenv("TARGET_RETURN_RATE", 0.05))
ECOS_API_KEY = os.getenv("ECOS_API_KEY")
PREDICTION_OUTPUT_PATH = config_json.get("PREDICTION_OUTPUT_PATH", os.getenv("PREDICTION_OUTPUT_PATH"))

# 예시: 설정 값 출력 (필요 시 제거 가능)
if __name__ == "__main__":
    print("Configuration Loaded Successfully:")
    for key in dir():
        if not key.startswith("__") and key.isupper():
            print(f"{key}: {globals()[key]}")
